@@ -1,19 +1,5 @@
-/*=========================================================================
-
-  Program:   DICOMParser
-  Module:    DICOMParser.cxx
-  Language:  C++
-
-  Copyright (c) 2003 Matt Turek
-  All rights reserved.
-  See Copyright.txt for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
-
+// SPDX-FileCopyrightText: Copyright (c) 2003 Matt Turek
+// SPDX-License-Identifier: BSD-4-Clause
 #ifdef _MSC_VER
 #pragma warning(disable : 4514)
 #pragma warning(disable : 4786)
@@ -44,20 +30,14 @@
 
 #define DICOMPARSER_IGNORE_MAGIC_NUMBER
 
+VTK_ABI_NAMESPACE_BEGIN
 static const char* DICOM_MAGIC = "DICM";
 static const int OPTIONAL_SKIP = 128;
 
 class DICOMParserImplementation
 {
 public:
-  DICOMParserImplementation()
-    : Groups()
-    , Elements()
-    , Datatypes()
-    , Map()
-    , TypeMap(){
-
-    };
+  DICOMParserImplementation() = default;
 
   dicom_stl::vector<doublebyte> Groups;
   dicom_stl::vector<doublebyte> Elements;
@@ -78,7 +58,6 @@ public:
 };
 
 DICOMParser::DICOMParser()
-  : ParserOutputFile()
 {
   this->Implementation = new DICOMParserImplementation();
   this->DataFile = nullptr;
@@ -149,7 +128,7 @@ DICOMParser::~DICOMParser()
 
 bool DICOMParser::ReadHeader()
 {
-  bool dicom = this->IsDICOMFile(this->DataFile);
+  bool dicom = DICOMParser::IsDICOMFile(this->DataFile);
   if (!dicom)
   {
     return false;
@@ -255,7 +234,6 @@ bool DICOMParser::IsValidRepresentation(doublebyte rep, quadbyte& len, VRTypes&
     case DICOMParser::VR_PN:
     case DICOMParser::VR_ST:
     case DICOMParser::VR_TM:
-    case DICOMParser::VR_UT: // new
     case DICOMParser::VR_SH:
     case DICOMParser::VR_FL:
     case DICOMParser::VR_SL:
@@ -271,6 +249,7 @@ bool DICOMParser::IsValidRepresentation(doublebyte rep, quadbyte& len, VRTypes&
     case DICOMParser::VR_OB: // OB - LE
     case DICOMParser::VR_OW:
     case DICOMParser::VR_UN:
+    case DICOMParser::VR_UT:
     case DICOMParser::VR_SQ:
       DataFile->ReadDoubleByte();
       len = DataFile->ReadQuadByte();
@@ -403,7 +382,7 @@ void DICOMParser::ReadNextRecord(
     }
     else
     {
-      if (this->DataFile->GetPlatformIsBigEndian() == true)
+      if (this->DataFile->GetPlatformIsBigEndian())
       {
         size_t uLength = static_cast<size_t>(length);
         switch (callbackType)
@@ -594,8 +573,6 @@ void DICOMParser::DumpTag(dicom_stream::ostream& out, doublebyte group, doubleby
   out << dicom_stream::dec << dicom_stream::endl;
   out.fill(prev);
   out << dicom_stream::dec;
-
-  return;
 }
 
 void DICOMParser::ModalityTag(doublebyte, doublebyte, VRTypes, unsigned char* tempdata, quadbyte)
@@ -785,3 +762,4 @@ void DICOMParser::operator=(const DICOMParser&)
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
+VTK_ABI_NAMESPACE_END
